==> artifician-0.6.1.tar.gz: artifician-0.6.1/docs/markdown/advanced_concepts.md <==
# Advanced Concepts

The Artifician library is designed to be easy to use for simple tasks, yet flexible enough for complex data preparation workflows. In this section, we will delve into the more advanced features and architectural choices that power the Artifician library.

## [Processor Chain Manager](processor_chain_manager.md)
  * [Overview](processor_chain_manager.md#overview)
  * [Key Features](processor_chain_manager.md#key-features)
  * [Syntax Showcase](processor_chain_manager.md#syntax-showcase)
  * [Example Scenario: NLP Processing Pipeline](processor_chain_manager.md#example-scenario-nlp-processing-pipeline)
  * [Building an NLP Pipeline with PCM](processor_chain_manager.md#building-an-nlp-pipeline-with-pcm)
  * [Output](processor_chain_manager.md#output)
## [Defining Custom Extractors](define_extractors.md)
  * [Introduction](define_extractors.md#introduction)
  * [Why Custom Extractors?](define_extractors.md#why-custom-extractors)
  * [How Extractors Work?](define_extractors.md#how-extractors-work)
  * [Example of a Simple Extractor](define_extractors.md#example-of-a-simple-extractor)
  * [Integrating Custom Extractors](define_extractors.md#integrating-custom-extractors)
  * [Advanced Usage](define_extractors.md#advanced-usage)
  * [Conclusion](define_extractors.md#conclusion)
## [Defining Custom Processors](define_processor.md)
  * [Introduction](define_processor.md#introduction)
  * [Why Custom Processors?](define_processor.md#why-custom-processors)
  * [How Processors Work?](define_processor.md#how-processors-work)
  * [Example of a Simple Processor](define_processor.md#example-of-a-simple-processor)
  * [Integrating Custom Processors](define_processor.md#integrating-custom-processors)
  * [Advanced Usage](define_processor.md#advanced-usage)
  * [Conclusion](define_processor.md#conclusion)
## [Library Architecture](library_architecture.md)
  * [Events](library_architecture.md#events)
  * [Dataset](library_architecture.md#dataset)
  * [Feature Definition](library_architecture.md#feature-definition)
  * [Processors](library_architecture.md#processors)
  * [Extractors](library_architecture.md#extractors)

Whether you’re looking to extend the library’s capabilities or trying to get a deeper understanding of how things work, these advanced topics will provide you with the knowledge you need.

==> artifician-0.6.2.tar.gz: artifician-0.6.2/docs/markdown/advanced_concepts.md <==
# Advanced Concepts

The Artifician library is designed to be easy to use for simple tasks, yet flexible enough for complex data preparation workflows. In this section, we will delve into the more advanced features and architectural choices that power the Artifician library.

## [Processor Chaining](processor_chaining.md)
  * [Overview](processor_chaining.md#overview)
  * [Key Features](processor_chaining.md#key-features)
  * [Syntax Showcase](processor_chaining.md#syntax-showcase)
  * [Example Scenario: NLP Processing Pipeline](processor_chaining.md#example-scenario-nlp-processing-pipeline)
  * [Building an NLP Pipeline with PCM](processor_chaining.md#building-an-nlp-pipeline-with-pcm)
  * [Output](processor_chaining.md#output)
## [Defining Custom Extractors](define_extractors.md)
  * [Introduction](define_extractors.md#introduction)
  * [Why Custom Extractors?](define_extractors.md#why-custom-extractors)
  * [How Extractors Work?](define_extractors.md#how-extractors-work)
  * [Example of a Simple Extractor](define_extractors.md#example-of-a-simple-extractor)
  * [Integrating Custom Extractors](define_extractors.md#integrating-custom-extractors)
  * [Advanced Usage](define_extractors.md#advanced-usage)
  * [Conclusion](define_extractors.md#conclusion)
## [Defining Custom Processors](define_processor.md)
  * [Introduction](define_processor.md#introduction)
  * [Why Custom Processors?](define_processor.md#why-custom-processors)
  * [How Processors Work?](define_processor.md#how-processors-work)
  * [Example of a Simple Processor](define_processor.md#example-of-a-simple-processor)
  * [Integrating Custom Processors](define_processor.md#integrating-custom-processors)
  * [Advanced Usage](define_processor.md#advanced-usage)
  * [Conclusion](define_processor.md#conclusion)
## [Library Architecture](library_architecture.md)
  * [Events](library_architecture.md#events)
  * [Dataset](library_architecture.md#dataset)
  * [Feature Definition](library_architecture.md#feature-definition)
  * [Processors](library_architecture.md#processors)
  * [Extractors](library_architecture.md#extractors)

Whether you’re looking to extend the library’s capabilities or trying to get a deeper understanding of how things work, these advanced topics will provide you with the knowledge you need.
